package pt.ulisboa.tecnico.ref.algorithm.feature.generation.impl;

import java.util.ArrayList;
import java.util.List;

import edu.columbia.cs.ref.algorithm.feature.generation.CandidateSentenceFeatureGenerator;
import edu.columbia.cs.ref.algorithm.feature.generation.FeatureGenerator;
import edu.columbia.cs.ref.model.CandidateSentence;
import edu.columbia.cs.ref.model.feature.FeatureSet;
import edu.columbia.cs.ref.model.feature.impl.SequenceFS;
import edu.columbia.cs.utils.Stemmer;

/**
 * The Class StringPatttern1FG is a candidate sentence feature generator
 * that produces capitalization tags according to a pattern where a char
 * in a String is replace by a symbols depending if it is a 
 * capital letter with symbol A, a lowercase with symbol a, and a number with 0
 * 
 * @author Joao L. M. Pereira
 * @author Goncalo Simoes
 * @version 0.1
 * @since 2015-06-18
 */

public class StringPatttern1FG extends
		CandidateSentenceFeatureGenerator<SequenceFS<String>> {

	/** The tokenizer. */
	private FeatureGenerator<SequenceFS<String>> tokenizer;

	public StringPatttern1FG(FeatureGenerator<SequenceFS<String>> tokenizer) {
		this.tokenizer = tokenizer;
	}

	@Override
	protected SequenceFS<String> extractFeatures(CandidateSentence sentence) {
		SequenceFS<String> tokenization = sentence.getFeatures(tokenizer);
		String[] tokens = tokenization.toArray();
		String[] pat = new String[tokens.length];

		for (int i = 0; i < tokens.length; i++) {
			pat[i] = tokens[i].replaceAll("[A-Z]","A").replaceAll("[a-z]","a").
					replaceAll("[0-9]","0");
		}
		return new SequenceFS<String>(pat);
	}

	@Override
	protected List retrieveRequiredFeatureGenerators() {
		ArrayList<FeatureGenerator> ret = new ArrayList<FeatureGenerator>();

		ret.add(tokenizer);

		return ret;
	}

}
